Class: Aws::StorageGateway::Types::CacheReportFilter

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-storagegateway/types.rb

Overview

A list of filter parameters and associated values that determine which files are included or excluded from a cache report created by a StartCacheReport request. Multiple instances of the same filter parameter are combined with an OR operation, while different parameters are combined with an AND operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

The parameter name for a filter that determines which files are included or excluded from a cache report.

**Valid Names:**

UploadFailureReason | UploadState

Returns:



733
734
735
736
737
738
# File 'lib/aws-sdk-storagegateway/types.rb', line 733

class CacheReportFilter < Struct.new(
  :name,
  :values)
  SENSITIVE = []
  include Aws::Structure
end

#valuesArray<String>

The parameter value for a filter that determines which files are included or excluded from a cache report.

**Valid UploadFailureReason Values:**

InaccessibleStorageClass | InvalidObjectState | ObjectMissing | S3AccessDenied

**Valid UploadState Values:**

FailingUpload

Returns:



733
734
735
736
737
738
# File 'lib/aws-sdk-storagegateway/types.rb', line 733

class CacheReportFilter < Struct.new(
  :name,
  :values)
  SENSITIVE = []
  include Aws::Structure
end