Class: Aws::StorageGateway::Types::CreateStorediSCSIVolumeInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::StorageGateway::Types::CreateStorediSCSIVolumeInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-storagegateway/types.rb
Overview
A JSON object containing one or more of the following fields:
-
CreateStorediSCSIVolumeInput$DiskId
-
CreateStorediSCSIVolumeInput$NetworkInterfaceId
-
CreateStorediSCSIVolumeInput$PreserveExistingData
-
CreateStorediSCSIVolumeInput$SnapshotId
-
CreateStorediSCSIVolumeInput$TargetName
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#disk_id ⇒ String
The unique identifier for the gateway local disk that is configured as a stored volume.
-
#gateway_arn ⇒ String
The Amazon Resource Name (ARN) of the gateway.
-
#kms_encrypted ⇒ Boolean
Set to
trueto use Amazon S3 server-side encryption with your own KMS key, orfalseto use a key managed by Amazon S3. -
#kms_key ⇒ String
The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used for Amazon S3 server-side encryption.
-
#network_interface_id ⇒ String
The network interface of the gateway on which to expose the iSCSI target.
-
#preserve_existing_data ⇒ Boolean
Set to
trueif you want to preserve the data on the local disk. -
#snapshot_id ⇒ String
The snapshot ID (e.g., “snap-1122aabb”) of the snapshot to restore as the new stored volume.
-
#tags ⇒ Array<Types::Tag>
A list of up to 50 tags that can be assigned to a stored volume.
-
#target_name ⇒ String
The name of the iSCSI target used by an initiator to connect to a volume and used as a suffix for the target ARN.
Instance Attribute Details
#disk_id ⇒ String
The unique identifier for the gateway local disk that is configured as a stored volume. Use [ListLocalDisks] to list disk IDs for a gateway.
[1]: docs.aws.amazon.com/storagegateway/latest/userguide/API_ListLocalDisks.html
2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2049 class CreateStorediSCSIVolumeInput < Struct.new( :gateway_arn, :disk_id, :snapshot_id, :preserve_existing_data, :target_name, :network_interface_id, :kms_encrypted, :kms_key, :tags) SENSITIVE = [] include Aws::Structure end |
#gateway_arn ⇒ String
The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Amazon Web Services Region.
2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2049 class CreateStorediSCSIVolumeInput < Struct.new( :gateway_arn, :disk_id, :snapshot_id, :preserve_existing_data, :target_name, :network_interface_id, :kms_encrypted, :kms_key, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_encrypted ⇒ Boolean
Set to true to use Amazon S3 server-side encryption with your own KMS key, or false to use a key managed by Amazon S3. Optional.
Valid Values: true | false
2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2049 class CreateStorediSCSIVolumeInput < Struct.new( :gateway_arn, :disk_id, :snapshot_id, :preserve_existing_data, :target_name, :network_interface_id, :kms_encrypted, :kms_key, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_key ⇒ String
The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used for Amazon S3 server-side encryption. Storage Gateway does not support asymmetric CMKs. This value can only be set when KMSEncrypted is true. Optional.
2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2049 class CreateStorediSCSIVolumeInput < Struct.new( :gateway_arn, :disk_id, :snapshot_id, :preserve_existing_data, :target_name, :network_interface_id, :kms_encrypted, :kms_key, :tags) SENSITIVE = [] include Aws::Structure end |
#network_interface_id ⇒ String
The network interface of the gateway on which to expose the iSCSI target. Accepts IPv4 and IPv6 addresses. Use DescribeGatewayInformation to get a list of the network interfaces available on a gateway.
Valid Values: A valid IP address.
2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2049 class CreateStorediSCSIVolumeInput < Struct.new( :gateway_arn, :disk_id, :snapshot_id, :preserve_existing_data, :target_name, :network_interface_id, :kms_encrypted, :kms_key, :tags) SENSITIVE = [] include Aws::Structure end |
#preserve_existing_data ⇒ Boolean
Set to true if you want to preserve the data on the local disk. Otherwise, set to false to create an empty volume.
Valid Values: true | false
2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2049 class CreateStorediSCSIVolumeInput < Struct.new( :gateway_arn, :disk_id, :snapshot_id, :preserve_existing_data, :target_name, :network_interface_id, :kms_encrypted, :kms_key, :tags) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The snapshot ID (e.g., “snap-1122aabb”) of the snapshot to restore as the new stored volume. Specify this field if you want to create the iSCSI storage volume from a snapshot; otherwise, do not include this field. To list snapshots for your account use
- DescribeSnapshots][1
-
in the *Amazon Elastic Compute Cloud API
Reference*.
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/ApiReference-query-DescribeSnapshots.html
2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2049 class CreateStorediSCSIVolumeInput < Struct.new( :gateway_arn, :disk_id, :snapshot_id, :preserve_existing_data, :target_name, :network_interface_id, :kms_encrypted, :kms_key, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of up to 50 tags that can be assigned to a stored volume. Each tag is a key-value pair.
<note markdown=“1”> Valid characters for key and value are letters, spaces, and numbers representable in UTF-8 format, and the following special characters: + - = . _ : / @. The maximum length of a tag’s key is 128 characters, and the maximum length for a tag’s value is 256.
</note>
2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2049 class CreateStorediSCSIVolumeInput < Struct.new( :gateway_arn, :disk_id, :snapshot_id, :preserve_existing_data, :target_name, :network_interface_id, :kms_encrypted, :kms_key, :tags) SENSITIVE = [] include Aws::Structure end |
#target_name ⇒ String
The name of the iSCSI target used by an initiator to connect to a volume and used as a suffix for the target ARN. For example, specifying TargetName as myvolume results in the target ARN of arn:aws:storagegateway:us-east-2:111122223333:gateway/sgw-12A3456B/target/iqn.1997-05.com.amazon:myvolume. The target name must be unique across all volumes on a gateway.
If you don’t specify a value, Storage Gateway uses the value that was previously used for this volume as the new target name.
2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 2059 2060 2061 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2049 class CreateStorediSCSIVolumeInput < Struct.new( :gateway_arn, :disk_id, :snapshot_id, :preserve_existing_data, :target_name, :network_interface_id, :kms_encrypted, :kms_key, :tags) SENSITIVE = [] include Aws::Structure end |