Class: Aws::StorageGateway::Types::CreateTapesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::StorageGateway::Types::CreateTapesInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-storagegateway/types.rb
Overview
CreateTapesInput
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique identifier that you use to retry a request.
-
#gateway_arn ⇒ String
The unique Amazon Resource Name (ARN) that represents the gateway to associate the virtual tapes with.
-
#kms_encrypted ⇒ Boolean
Set to
trueto use Amazon S3 server-side encryption with your own KMS key, orfalseto use a key managed by Amazon S3. -
#kms_key ⇒ String
The Amazon Resource Name (ARN) of a symmetric customer master key (CMK) used for Amazon S3 server-side encryption.
-
#num_tapes_to_create ⇒ Integer
The number of virtual tapes that you want to create.
-
#pool_id ⇒ String
The ID of the pool that you want to add your tape to for archiving.
-
#tags ⇒ Array<Types::Tag>
A list of up to 50 tags that can be assigned to a virtual tape.
-
#tape_barcode_prefix ⇒ String
A prefix that you append to the barcode of the virtual tape you are creating.
-
#tape_size_in_bytes ⇒ Integer
The size, in bytes, of the virtual tapes that you want to create.
-
#worm ⇒ Boolean
Set to
TRUEif the tape you are creating is to be configured as a write-once-read-many (WORM) tape.
Instance Attribute Details
#client_token ⇒ String
A unique identifier that you use to retry a request. If you retry a
request, use the same ClientToken you specified in the initial
request.
ClientToken prevents creating the tape multiple
times.
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2330 class CreateTapesInput < Struct.new( :gateway_arn, :tape_size_in_bytes, :client_token, :num_tapes_to_create, :tape_barcode_prefix, :kms_encrypted, :kms_key, :pool_id, :worm, :tags) SENSITIVE = [] include Aws::Structure end |
#gateway_arn ⇒ String
The unique Amazon Resource Name (ARN) that represents the gateway to associate the virtual tapes with. Use the ListGateways operation to return a list of gateways for your account and Amazon Web Services Region.
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2330 class CreateTapesInput < Struct.new( :gateway_arn, :tape_size_in_bytes, :client_token, :num_tapes_to_create, :tape_barcode_prefix, :kms_encrypted, :kms_key, :pool_id, :worm, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_encrypted ⇒ Boolean
Set to true to use Amazon S3 server-side encryption with your own
KMS key, or false to use a key managed by Amazon S3. Optional.
Valid Values: true | false
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2330 class CreateTapesInput < Struct.new( :gateway_arn, :tape_size_in_bytes, :client_token, :num_tapes_to_create, :tape_barcode_prefix, :kms_encrypted, :kms_key, :pool_id, :worm, :tags) SENSITIVE = [] include Aws::Structure end |
#kms_key ⇒ String
The Amazon Resource Name (ARN) of a symmetric customer master key
(CMK) used for Amazon S3 server-side encryption. Storage Gateway
does not support asymmetric CMKs. This value can only be set when
KMSEncrypted is true. Optional.
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2330 class CreateTapesInput < Struct.new( :gateway_arn, :tape_size_in_bytes, :client_token, :num_tapes_to_create, :tape_barcode_prefix, :kms_encrypted, :kms_key, :pool_id, :worm, :tags) SENSITIVE = [] include Aws::Structure end |
#num_tapes_to_create ⇒ Integer
The number of virtual tapes that you want to create.
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2330 class CreateTapesInput < Struct.new( :gateway_arn, :tape_size_in_bytes, :client_token, :num_tapes_to_create, :tape_barcode_prefix, :kms_encrypted, :kms_key, :pool_id, :worm, :tags) SENSITIVE = [] include Aws::Structure end |
#pool_id ⇒ String
The ID of the pool that you want to add your tape to for archiving. The tape in this pool is archived in the S3 storage class that is associated with the pool. When you use your backup application to eject the tape, the tape is archived directly into the storage class (S3 Glacier or S3 Glacier Deep Archive) that corresponds to the pool.
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2330 class CreateTapesInput < Struct.new( :gateway_arn, :tape_size_in_bytes, :client_token, :num_tapes_to_create, :tape_barcode_prefix, :kms_encrypted, :kms_key, :pool_id, :worm, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of up to 50 tags that can be assigned to a virtual tape. Each tag is a key-value pair.
-
-
. _ : / @. The maximum length of a tag's key is 128
characters, and the maximum length for a tag's value is 256.
-
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2330 class CreateTapesInput < Struct.new( :gateway_arn, :tape_size_in_bytes, :client_token, :num_tapes_to_create, :tape_barcode_prefix, :kms_encrypted, :kms_key, :pool_id, :worm, :tags) SENSITIVE = [] include Aws::Structure end |
#tape_barcode_prefix ⇒ String
A prefix that you append to the barcode of the virtual tape you are creating. This prefix makes the barcode unique.
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2330 class CreateTapesInput < Struct.new( :gateway_arn, :tape_size_in_bytes, :client_token, :num_tapes_to_create, :tape_barcode_prefix, :kms_encrypted, :kms_key, :pool_id, :worm, :tags) SENSITIVE = [] include Aws::Structure end |
#tape_size_in_bytes ⇒ Integer
The size, in bytes, of the virtual tapes that you want to create.
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2330 class CreateTapesInput < Struct.new( :gateway_arn, :tape_size_in_bytes, :client_token, :num_tapes_to_create, :tape_barcode_prefix, :kms_encrypted, :kms_key, :pool_id, :worm, :tags) SENSITIVE = [] include Aws::Structure end |
#worm ⇒ Boolean
Set to TRUE if the tape you are creating is to be configured as a
write-once-read-many (WORM) tape.
2330 2331 2332 2333 2334 2335 2336 2337 2338 2339 2340 2341 2342 2343 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2330 class CreateTapesInput < Struct.new( :gateway_arn, :tape_size_in_bytes, :client_token, :num_tapes_to_create, :tape_barcode_prefix, :kms_encrypted, :kms_key, :pool_id, :worm, :tags) SENSITIVE = [] include Aws::Structure end |