Class: Aws::StorageGateway::Types::DeleteTapeArchiveInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::StorageGateway::Types::DeleteTapeArchiveInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-storagegateway/types.rb
Overview
DeleteTapeArchiveInput
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bypass_governance_retention ⇒ Boolean
Set to
TRUEto delete an archived tape that belongs to a custom pool with tape retention lock. -
#tape_arn ⇒ String
The Amazon Resource Name (ARN) of the virtual tape to delete from the virtual tape shelf (VTS).
Instance Attribute Details
#bypass_governance_retention ⇒ Boolean
Set to TRUE to delete an archived tape that belongs to a custom pool with tape retention lock. Only archived tapes with tape retention lock set to governance can be deleted. Archived tapes with tape retention lock set to compliance can’t be deleted.
2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2614 class DeleteTapeArchiveInput < Struct.new( :tape_arn, :bypass_governance_retention) SENSITIVE = [] include Aws::Structure end |
#tape_arn ⇒ String
The Amazon Resource Name (ARN) of the virtual tape to delete from the virtual tape shelf (VTS).
2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2614 class DeleteTapeArchiveInput < Struct.new( :tape_arn, :bypass_governance_retention) SENSITIVE = [] include Aws::Structure end |