Class: Aws::StorageGateway::Types::DeleteTapeInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::StorageGateway::Types::DeleteTapeInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-storagegateway/types.rb
Overview
DeleteTapeInput
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bypass_governance_retention ⇒ Boolean
Set to
TRUEto delete an archived tape that belongs to a custom pool with tape retention lock. -
#gateway_arn ⇒ String
The unique Amazon Resource Name (ARN) of the gateway that the virtual tape to delete is associated with.
-
#tape_arn ⇒ String
The Amazon Resource Name (ARN) of the virtual tape to delete.
Instance Attribute Details
#bypass_governance_retention ⇒ Boolean
Set to TRUE to delete an archived tape that belongs to a custom pool with tape retention lock. Only archived tapes with tape retention lock set to governance can be deleted. Archived tapes with tape retention lock set to compliance can’t be deleted.
2658 2659 2660 2661 2662 2663 2664 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2658 class DeleteTapeInput < Struct.new( :gateway_arn, :tape_arn, :bypass_governance_retention) SENSITIVE = [] include Aws::Structure end |
#gateway_arn ⇒ String
The unique Amazon Resource Name (ARN) of the gateway that the virtual tape to delete is associated with. Use the ListGateways operation to return a list of gateways for your account and Amazon Web Services Region.
2658 2659 2660 2661 2662 2663 2664 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2658 class DeleteTapeInput < Struct.new( :gateway_arn, :tape_arn, :bypass_governance_retention) SENSITIVE = [] include Aws::Structure end |
#tape_arn ⇒ String
The Amazon Resource Name (ARN) of the virtual tape to delete.
2658 2659 2660 2661 2662 2663 2664 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 2658 class DeleteTapeInput < Struct.new( :gateway_arn, :tape_arn, :bypass_governance_retention) SENSITIVE = [] include Aws::Structure end |