Class: Aws::StorageGateway::Types::DescribeCacheReportOutput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-storagegateway/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cache_report_infoTypes::CacheReportInfo

Contains all informational fields associated with a cache report. Includes name, ARN, tags, status, progress, filters, start time, and end time.

Returns:



2946
2947
2948
2949
2950
# File 'lib/aws-sdk-storagegateway/types.rb', line 2946

class DescribeCacheReportOutput < Struct.new(
  :cache_report_info)
  SENSITIVE = []
  include Aws::Structure
end