Class: Aws::StorageGateway::Types::DescribeVTLDevicesInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-storagegateway/types.rb

Overview

DescribeVTLDevicesInput

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#gateway_arnString

The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Amazon Web Services Region.

Returns:

  • (String)


3901
3902
3903
3904
3905
3906
3907
3908
# File 'lib/aws-sdk-storagegateway/types.rb', line 3901

class DescribeVTLDevicesInput < Struct.new(
  :gateway_arn,
  :vtl_device_arns,
  :marker,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#limitInteger

Specifies that the number of VTL devices described be limited to the specified number.

Returns:

  • (Integer)


3901
3902
3903
3904
3905
3906
3907
3908
# File 'lib/aws-sdk-storagegateway/types.rb', line 3901

class DescribeVTLDevicesInput < Struct.new(
  :gateway_arn,
  :vtl_device_arns,
  :marker,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An opaque string that indicates the position at which to begin describing the VTL devices.

Returns:

  • (String)


3901
3902
3903
3904
3905
3906
3907
3908
# File 'lib/aws-sdk-storagegateway/types.rb', line 3901

class DescribeVTLDevicesInput < Struct.new(
  :gateway_arn,
  :vtl_device_arns,
  :marker,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end

#vtl_device_arnsArray<String>

An array of strings, where each string represents the Amazon Resource Name (ARN) of a VTL device.

All of the specified VTL devices must be from the same gateway. If no VTL devices are specified, the result will contain all devices on the specified gateway.

Returns:

  • (Array<String>)


3901
3902
3903
3904
3905
3906
3907
3908
# File 'lib/aws-sdk-storagegateway/types.rb', line 3901

class DescribeVTLDevicesInput < Struct.new(
  :gateway_arn,
  :vtl_device_arns,
  :marker,
  :limit)
  SENSITIVE = []
  include Aws::Structure
end