Class: Aws::StorageGateway::Types::DetachVolumeInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-storagegateway/types.rb

Overview

AttachVolumeInput

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#force_detachBoolean

Set to true to forcibly remove the iSCSI connection of the target volume and detach the volume. The default is false. If this value is set to false, you must manually disconnect the iSCSI connection from the target volume.

Valid Values: true | false

Returns:

  • (Boolean)


4012
4013
4014
4015
4016
4017
# File 'lib/aws-sdk-storagegateway/types.rb', line 4012

class DetachVolumeInput < Struct.new(
  :volume_arn,
  :force_detach)
  SENSITIVE = []
  include Aws::Structure
end

#volume_arnString

The Amazon Resource Name (ARN) of the volume to detach from the gateway.

Returns:

  • (String)


4012
4013
4014
4015
4016
4017
# File 'lib/aws-sdk-storagegateway/types.rb', line 4012

class DetachVolumeInput < Struct.new(
  :volume_arn,
  :force_detach)
  SENSITIVE = []
  include Aws::Structure
end