Class: Aws::StorageGateway::Types::InternalServerError

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-storagegateway/types.rb

Overview

An internal server error has occurred during the request. For more information, see the error and message fields.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#errorTypes::StorageGatewayError

A StorageGatewayError that provides more information about the cause of the error.

Returns:



4518
4519
4520
4521
4522
4523
# File 'lib/aws-sdk-storagegateway/types.rb', line 4518

class InternalServerError < Struct.new(
  :message,
  :error)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A human-readable message describing the error that occurred.

Returns:



4518
4519
4520
4521
4522
4523
# File 'lib/aws-sdk-storagegateway/types.rb', line 4518

class InternalServerError < Struct.new(
  :message,
  :error)
  SENSITIVE = []
  include Aws::Structure
end