Class: Aws::StorageGateway::Types::ListFileSharesInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-storagegateway/types.rb

Overview

ListFileShareInput

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#gateway_arnString

The Amazon Resource Name (ARN) of the gateway whose file shares you want to list. If this field is not present, all file shares under your account are listed.

Returns:

  • (String)


4744
4745
4746
4747
4748
4749
4750
# File 'lib/aws-sdk-storagegateway/types.rb', line 4744

class ListFileSharesInput < Struct.new(
  :gateway_arn,
  :limit,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#limitInteger

The maximum number of file shares to return in the response. The value must be an integer with a value greater than zero. Optional.

Returns:

  • (Integer)


4744
4745
4746
4747
4748
4749
4750
# File 'lib/aws-sdk-storagegateway/types.rb', line 4744

class ListFileSharesInput < Struct.new(
  :gateway_arn,
  :limit,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

Opaque pagination token returned from a previous ListFileShares operation. If present, Marker specifies where to continue the list from after a previous call to ListFileShares. Optional.

Returns:

  • (String)


4744
4745
4746
4747
4748
4749
4750
# File 'lib/aws-sdk-storagegateway/types.rb', line 4744

class ListFileSharesInput < Struct.new(
  :gateway_arn,
  :limit,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end