Class: Aws::StorageGateway::Types::ListVolumesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::StorageGateway::Types::ListVolumesOutput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-storagegateway/types.rb
Overview
A JSON object containing the following fields:
-
ListVolumesOutput$Marker
-
ListVolumesOutput$VolumeInfos
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#gateway_arn ⇒ String
The Amazon Resource Name (ARN) of the gateway.
-
#marker ⇒ String
Use the marker in your next request to continue pagination of iSCSI volumes.
-
#volume_infos ⇒ Array<Types::VolumeInfo>
An array of VolumeInfo objects, where each object describes an iSCSI volume.
Instance Attribute Details
#gateway_arn ⇒ String
The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Amazon Web Services Region.
5203 5204 5205 5206 5207 5208 5209 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 5203 class ListVolumesOutput < Struct.new( :gateway_arn, :marker, :volume_infos) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Use the marker in your next request to continue pagination of iSCSI volumes. If there are no more volumes to list, this field does not appear in the response body.
5203 5204 5205 5206 5207 5208 5209 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 5203 class ListVolumesOutput < Struct.new( :gateway_arn, :marker, :volume_infos) SENSITIVE = [] include Aws::Structure end |
#volume_infos ⇒ Array<Types::VolumeInfo>
An array of VolumeInfo objects, where each object describes an iSCSI volume. If no volumes are defined for the gateway, then ‘VolumeInfos` is an empty array “[]”.
5203 5204 5205 5206 5207 5208 5209 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 5203 class ListVolumesOutput < Struct.new( :gateway_arn, :marker, :volume_infos) SENSITIVE = [] include Aws::Structure end |