Class: Aws::StorageGateway::Types::RefreshCacheInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::StorageGateway::Types::RefreshCacheInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-storagegateway/types.rb
Overview
RefreshCacheInput
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#file_share_arn ⇒ String
The Amazon Resource Name (ARN) of the file share you want to refresh.
-
#folder_list ⇒ Array<String>
A comma-separated list of the paths of folders to refresh in the cache.
-
#recursive ⇒ Boolean
A value that specifies whether to recursively refresh folders in the cache.
Instance Attribute Details
#file_share_arn ⇒ String
The Amazon Resource Name (ARN) of the file share you want to refresh.
5690 5691 5692 5693 5694 5695 5696 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 5690 class RefreshCacheInput < Struct.new( :file_share_arn, :folder_list, :recursive) SENSITIVE = [] include Aws::Structure end |
#folder_list ⇒ Array<String>
A comma-separated list of the paths of folders to refresh in the
cache. The default is ["/"]. The default refreshes objects and
folders at the root of the Amazon S3 bucket. If Recursive is set
to true, the entire S3 bucket that the file share has access to is
refreshed.
Do not include / when specifying folder names. For example, you
would specify samplefolder rather than samplefolder/.
5690 5691 5692 5693 5694 5695 5696 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 5690 class RefreshCacheInput < Struct.new( :file_share_arn, :folder_list, :recursive) SENSITIVE = [] include Aws::Structure end |
#recursive ⇒ Boolean
A value that specifies whether to recursively refresh folders in the
cache. The refresh includes folders that were in the cache the last
time the gateway listed the folder's contents. If this value set to
true, each folder that is listed in FolderList is recursively
updated. Otherwise, subfolders listed in FolderList are not
refreshed. Only objects that are in folders listed directly under
FolderList are found and used for the update. The default is
true.
Valid Values: true | false
5690 5691 5692 5693 5694 5695 5696 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 5690 class RefreshCacheInput < Struct.new( :file_share_arn, :folder_list, :recursive) SENSITIVE = [] include Aws::Structure end |