Class: Aws::StorageGateway::Types::ServiceUnavailableError
- Inherits:
-
Struct
- Object
- Struct
- Aws::StorageGateway::Types::ServiceUnavailableError
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-storagegateway/types.rb
Overview
An internal server error has occurred because the service is unavailable. For more information, see the error and message fields.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error ⇒ Types::StorageGatewayError
A StorageGatewayError that provides more information about the cause of the error.
-
#message ⇒ String
A human-readable message describing the error that occurred.
Instance Attribute Details
#error ⇒ Types::StorageGatewayError
A StorageGatewayError that provides more information about the cause of the error.
6233 6234 6235 6236 6237 6238 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 6233 class ServiceUnavailableError < Struct.new( :message, :error) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
A human-readable message describing the error that occurred.
6233 6234 6235 6236 6237 6238 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 6233 class ServiceUnavailableError < Struct.new( :message, :error) SENSITIVE = [] include Aws::Structure end |