Class: Aws::StorageGateway::Types::StartCacheReportInput

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-storagegateway/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bucket_regionString

The Amazon Web Services Region of the Amazon S3 bucket where you want to save the cache report.

Returns:



6455
6456
6457
6458
6459
6460
6461
6462
6463
6464
6465
6466
6467
# File 'lib/aws-sdk-storagegateway/types.rb', line 6455

class StartCacheReportInput < Struct.new(
  :file_share_arn,
  :role,
  :location_arn,
  :bucket_region,
  :vpc_endpoint_dns_name,
  :inclusion_filters,
  :exclusion_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique identifier that you use to ensure idempotent report generation if you need to retry an unsuccessful StartCacheReport request. If you retry a request, use the same ClientToken you specified in the initial request.

Returns:



6455
6456
6457
6458
6459
6460
6461
6462
6463
6464
6465
6466
6467
# File 'lib/aws-sdk-storagegateway/types.rb', line 6455

class StartCacheReportInput < Struct.new(
  :file_share_arn,
  :role,
  :location_arn,
  :bucket_region,
  :vpc_endpoint_dns_name,
  :inclusion_filters,
  :exclusion_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#exclusion_filtersArray<Types::CacheReportFilter>

The list of filters and parameters that determine which files are excluded from the report. You must specify at least one value for InclusionFilters or ExclusionFilters in a StartCacheReport request.

Returns:



6455
6456
6457
6458
6459
6460
6461
6462
6463
6464
6465
6466
6467
# File 'lib/aws-sdk-storagegateway/types.rb', line 6455

class StartCacheReportInput < Struct.new(
  :file_share_arn,
  :role,
  :location_arn,
  :bucket_region,
  :vpc_endpoint_dns_name,
  :inclusion_filters,
  :exclusion_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#file_share_arnString

The Amazon Resource Name (ARN) of the file share.

Returns:



6455
6456
6457
6458
6459
6460
6461
6462
6463
6464
6465
6466
6467
# File 'lib/aws-sdk-storagegateway/types.rb', line 6455

class StartCacheReportInput < Struct.new(
  :file_share_arn,
  :role,
  :location_arn,
  :bucket_region,
  :vpc_endpoint_dns_name,
  :inclusion_filters,
  :exclusion_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#inclusion_filtersArray<Types::CacheReportFilter>

The list of filters and parameters that determine which files are included in the report. You must specify at least one value for InclusionFilters or ExclusionFilters in a StartCacheReport request.

Returns:



6455
6456
6457
6458
6459
6460
6461
6462
6463
6464
6465
6466
6467
# File 'lib/aws-sdk-storagegateway/types.rb', line 6455

class StartCacheReportInput < Struct.new(
  :file_share_arn,
  :role,
  :location_arn,
  :bucket_region,
  :vpc_endpoint_dns_name,
  :inclusion_filters,
  :exclusion_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#location_arnString

The ARN of the Amazon S3 bucket where you want to save the cache report.

<note markdown=“1”> We do not recommend saving the cache report to the same Amazon S3 bucket for which you are generating the report.

This field does not accept access point ARNs.

</note>

Returns:



6455
6456
6457
6458
6459
6460
6461
6462
6463
6464
6465
6466
6467
# File 'lib/aws-sdk-storagegateway/types.rb', line 6455

class StartCacheReportInput < Struct.new(
  :file_share_arn,
  :role,
  :location_arn,
  :bucket_region,
  :vpc_endpoint_dns_name,
  :inclusion_filters,
  :exclusion_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#roleString

The ARN of the IAM role used when saving the cache report to Amazon S3.

Returns:



6455
6456
6457
6458
6459
6460
6461
6462
6463
6464
6465
6466
6467
# File 'lib/aws-sdk-storagegateway/types.rb', line 6455

class StartCacheReportInput < Struct.new(
  :file_share_arn,
  :role,
  :location_arn,
  :bucket_region,
  :vpc_endpoint_dns_name,
  :inclusion_filters,
  :exclusion_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of up to 50 key/value tags that you can assign to the cache report. Using tags can help you categorize your reports and more easily locate them in search results.

Returns:



6455
6456
6457
6458
6459
6460
6461
6462
6463
6464
6465
6466
6467
# File 'lib/aws-sdk-storagegateway/types.rb', line 6455

class StartCacheReportInput < Struct.new(
  :file_share_arn,
  :role,
  :location_arn,
  :bucket_region,
  :vpc_endpoint_dns_name,
  :inclusion_filters,
  :exclusion_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_dns_nameString

The DNS name of the VPC endpoint associated with the Amazon S3 where you want to save the cache report. Optional.

Returns:



6455
6456
6457
6458
6459
6460
6461
6462
6463
6464
6465
6466
6467
# File 'lib/aws-sdk-storagegateway/types.rb', line 6455

class StartCacheReportInput < Struct.new(
  :file_share_arn,
  :role,
  :location_arn,
  :bucket_region,
  :vpc_endpoint_dns_name,
  :inclusion_filters,
  :exclusion_filters,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end