Class: Aws::StorageGateway::Types::UpdateNFSFileShareInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::StorageGateway::Types::UpdateNFSFileShareInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-storagegateway/types.rb
Overview
UpdateNFSFileShareInput
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audit_destination_arn ⇒ String
The Amazon Resource Name (ARN) of the storage used for audit logs.
-
#cache_attributes ⇒ Types::CacheAttributes
Specifies refresh cache information for the file share.
-
#client_list ⇒ Array<String>
The list of clients that are allowed to access the S3 File Gateway.
-
#default_storage_class ⇒ String
The default storage class for objects put into an Amazon S3 bucket by the S3 File Gateway.
-
#encryption_type ⇒ String
A value that specifies the type of server-side encryption that the file share will use for the data that it stores in Amazon S3.
-
#file_share_arn ⇒ String
The Amazon Resource Name (ARN) of the file share to be updated.
-
#file_share_name ⇒ String
The name of the file share.
-
#guess_mime_type_enabled ⇒ Boolean
A value that enables guessing of the MIME type for uploaded objects based on file extensions.
-
#kms_encrypted ⇒ Boolean
Optional.
-
#kms_key ⇒ String
Optional.
-
#nfs_file_share_defaults ⇒ Types::NFSFileShareDefaults
The default values for the file share.
-
#notification_policy ⇒ String
The notification policy of the file share.
-
#object_acl ⇒ String
A value that sets the access control list (ACL) permission for objects in the S3 bucket that a S3 File Gateway puts objects into.
-
#read_only ⇒ Boolean
A value that sets the write status of a file share.
-
#requester_pays ⇒ Boolean
A value that sets who pays the cost of the request and the cost associated with data download from the S3 bucket.
-
#squash ⇒ String
The user mapped to anonymous user.
Instance Attribute Details
#audit_destination_arn ⇒ String
The Amazon Resource Name (ARN) of the storage used for audit logs.
7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7570 class UpdateNFSFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :nfs_file_share_defaults, :default_storage_class, :object_acl, :client_list, :squash, :read_only, :guess_mime_type_enabled, :requester_pays, :file_share_name, :cache_attributes, :notification_policy, :audit_destination_arn) SENSITIVE = [] include Aws::Structure end |
#cache_attributes ⇒ Types::CacheAttributes
Specifies refresh cache information for the file share.
7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7570 class UpdateNFSFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :nfs_file_share_defaults, :default_storage_class, :object_acl, :client_list, :squash, :read_only, :guess_mime_type_enabled, :requester_pays, :file_share_name, :cache_attributes, :notification_policy, :audit_destination_arn) SENSITIVE = [] include Aws::Structure end |
#client_list ⇒ Array<String>
The list of clients that are allowed to access the S3 File Gateway. The list must contain either valid IPv4/IPv6 addresses or valid CIDR blocks.
7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7570 class UpdateNFSFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :nfs_file_share_defaults, :default_storage_class, :object_acl, :client_list, :squash, :read_only, :guess_mime_type_enabled, :requester_pays, :file_share_name, :cache_attributes, :notification_policy, :audit_destination_arn) SENSITIVE = [] include Aws::Structure end |
#default_storage_class ⇒ String
The default storage class for objects put into an Amazon S3 bucket
by the S3 File Gateway. The default value is S3_STANDARD.
Optional.
Valid Values: S3_STANDARD | S3_INTELLIGENT_TIERING |
S3_STANDARD_IA | S3_ONEZONE_IA
7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7570 class UpdateNFSFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :nfs_file_share_defaults, :default_storage_class, :object_acl, :client_list, :squash, :read_only, :guess_mime_type_enabled, :requester_pays, :file_share_name, :cache_attributes, :notification_policy, :audit_destination_arn) SENSITIVE = [] include Aws::Structure end |
#encryption_type ⇒ String
A value that specifies the type of server-side encryption that the file share will use for the data that it stores in Amazon S3.
EncryptionType instead of KMSEncrypted to set
the file share encryption method. You do not need to provide values
for both parameters.
If values for both parameters exist in the same request, then the
specified encryption methods must not conflict. For example, if
EncryptionType is SseS3, then KMSEncrypted must be false. If
EncryptionType is SseKms or DsseKms, then KMSEncrypted must
be true.
7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7570 class UpdateNFSFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :nfs_file_share_defaults, :default_storage_class, :object_acl, :client_list, :squash, :read_only, :guess_mime_type_enabled, :requester_pays, :file_share_name, :cache_attributes, :notification_policy, :audit_destination_arn) SENSITIVE = [] include Aws::Structure end |
#file_share_arn ⇒ String
The Amazon Resource Name (ARN) of the file share to be updated.
7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7570 class UpdateNFSFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :nfs_file_share_defaults, :default_storage_class, :object_acl, :client_list, :squash, :read_only, :guess_mime_type_enabled, :requester_pays, :file_share_name, :cache_attributes, :notification_policy, :audit_destination_arn) SENSITIVE = [] include Aws::Structure end |
#file_share_name ⇒ String
The name of the file share. Optional.
FileShareName must be set if an S3 prefix name is set in
LocationARN, or if an access point or access point alias is used.
A valid NFS file share name can only contain the following
characters: a-z, A-Z, 0-9, -, ., and _.
7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7570 class UpdateNFSFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :nfs_file_share_defaults, :default_storage_class, :object_acl, :client_list, :squash, :read_only, :guess_mime_type_enabled, :requester_pays, :file_share_name, :cache_attributes, :notification_policy, :audit_destination_arn) SENSITIVE = [] include Aws::Structure end |
#guess_mime_type_enabled ⇒ Boolean
A value that enables guessing of the MIME type for uploaded objects
based on file extensions. Set this value to true to enable MIME
type guessing, otherwise set to false. The default value is
true.
Valid Values: true | false
7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7570 class UpdateNFSFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :nfs_file_share_defaults, :default_storage_class, :object_acl, :client_list, :squash, :read_only, :guess_mime_type_enabled, :requester_pays, :file_share_name, :cache_attributes, :notification_policy, :audit_destination_arn) SENSITIVE = [] include Aws::Structure end |
#kms_encrypted ⇒ Boolean
Optional. Set to true to use Amazon S3 server-side encryption with
your own KMS key (SSE-KMS), or false to use a key managed by
Amazon S3 (SSE-S3). To use dual-layer encryption (DSSE-KMS), set the
EncryptionType parameter instead.
EncryptionType instead of KMSEncrypted to set
the file share encryption method. You do not need to provide values
for both parameters.
If values for both parameters exist in the same request, then the
specified encryption methods must not conflict. For example, if
EncryptionType is SseS3, then KMSEncrypted must be false. If
EncryptionType is SseKms or DsseKms, then KMSEncrypted must
be true.
Valid Values: true | false
7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7570 class UpdateNFSFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :nfs_file_share_defaults, :default_storage_class, :object_acl, :client_list, :squash, :read_only, :guess_mime_type_enabled, :requester_pays, :file_share_name, :cache_attributes, :notification_policy, :audit_destination_arn) SENSITIVE = [] include Aws::Structure end |
#kms_key ⇒ String
Optional. The Amazon Resource Name (ARN) of a symmetric customer
master key (CMK) used for Amazon S3 server-side encryption. Storage
Gateway does not support asymmetric CMKs. This value must be set if
KMSEncrypted is true, or if EncryptionType is SseKms or
DsseKms.
7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7570 class UpdateNFSFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :nfs_file_share_defaults, :default_storage_class, :object_acl, :client_list, :squash, :read_only, :guess_mime_type_enabled, :requester_pays, :file_share_name, :cache_attributes, :notification_policy, :audit_destination_arn) SENSITIVE = [] include Aws::Structure end |
#nfs_file_share_defaults ⇒ Types::NFSFileShareDefaults
The default values for the file share. Optional.
7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7570 class UpdateNFSFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :nfs_file_share_defaults, :default_storage_class, :object_acl, :client_list, :squash, :read_only, :guess_mime_type_enabled, :requester_pays, :file_share_name, :cache_attributes, :notification_policy, :audit_destination_arn) SENSITIVE = [] include Aws::Structure end |
#notification_policy ⇒ String
The notification policy of the file share. SettlingTimeInSeconds
controls the number of seconds to wait after the last point in time
a client wrote to a file before generating an ObjectUploaded
notification. Because clients can make many small writes to files,
it's best to set this parameter for as long as possible to avoid
generating multiple notifications for the same file in a small time
period.
SettlingTimeInSeconds has no effect on the timing of the object
uploading to Amazon S3, only the timing of the notification.
This setting is not meant to specify an exact time at which the notification will be sent. In some cases, the gateway might require more than the specified delay time to generate and send notifications.
The following example sets NotificationPolicy on with
SettlingTimeInSeconds set to 60.
{"Upload": {"SettlingTimeInSeconds": 60}}
The following example sets NotificationPolicy off.
{}
7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7570 class UpdateNFSFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :nfs_file_share_defaults, :default_storage_class, :object_acl, :client_list, :squash, :read_only, :guess_mime_type_enabled, :requester_pays, :file_share_name, :cache_attributes, :notification_policy, :audit_destination_arn) SENSITIVE = [] include Aws::Structure end |
#object_acl ⇒ String
A value that sets the access control list (ACL) permission for
objects in the S3 bucket that a S3 File Gateway puts objects into.
The default value is private.
7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7570 class UpdateNFSFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :nfs_file_share_defaults, :default_storage_class, :object_acl, :client_list, :squash, :read_only, :guess_mime_type_enabled, :requester_pays, :file_share_name, :cache_attributes, :notification_policy, :audit_destination_arn) SENSITIVE = [] include Aws::Structure end |
#read_only ⇒ Boolean
A value that sets the write status of a file share. Set this value
to true to set the write status to read-only, otherwise set to
false.
Valid Values: true | false
7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7570 class UpdateNFSFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :nfs_file_share_defaults, :default_storage_class, :object_acl, :client_list, :squash, :read_only, :guess_mime_type_enabled, :requester_pays, :file_share_name, :cache_attributes, :notification_policy, :audit_destination_arn) SENSITIVE = [] include Aws::Structure end |
#requester_pays ⇒ Boolean
A value that sets who pays the cost of the request and the cost
associated with data download from the S3 bucket. If this value is
set to true, the requester pays the costs; otherwise, the S3
bucket owner pays. However, the S3 bucket owner always pays the cost
of storing data.
RequesterPays is a configuration for the S3 bucket that backs the
file share, so make sure that the configuration on the file share is
the same as the S3 bucket configuration.
Valid Values: true | false
7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7570 class UpdateNFSFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :nfs_file_share_defaults, :default_storage_class, :object_acl, :client_list, :squash, :read_only, :guess_mime_type_enabled, :requester_pays, :file_share_name, :cache_attributes, :notification_policy, :audit_destination_arn) SENSITIVE = [] include Aws::Structure end |
#squash ⇒ String
The user mapped to anonymous user.
Valid values are the following:
-
RootSquash: Only root is mapped to anonymous user. -
NoSquash: No one is mapped to anonymous user. -
AllSquash: Everyone is mapped to anonymous user.
7570 7571 7572 7573 7574 7575 7576 7577 7578 7579 7580 7581 7582 7583 7584 7585 7586 7587 7588 7589 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7570 class UpdateNFSFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :nfs_file_share_defaults, :default_storage_class, :object_acl, :client_list, :squash, :read_only, :guess_mime_type_enabled, :requester_pays, :file_share_name, :cache_attributes, :notification_policy, :audit_destination_arn) SENSITIVE = [] include Aws::Structure end |