Class: Aws::StorageGateway::Types::UpdateSMBFileShareInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::StorageGateway::Types::UpdateSMBFileShareInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-storagegateway/types.rb
Overview
UpdateSMBFileShareInput
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_based_enumeration ⇒ Boolean
The files and folders on this share will only be visible to users with read access.
-
#admin_user_list ⇒ Array<String>
A list of users or groups in the Active Directory that have administrator rights to the file share.
-
#audit_destination_arn ⇒ String
The Amazon Resource Name (ARN) of the storage used for audit logs.
-
#cache_attributes ⇒ Types::CacheAttributes
Specifies refresh cache information for the file share.
-
#case_sensitivity ⇒ String
The case of an object name in an Amazon S3 bucket.
-
#default_storage_class ⇒ String
The default storage class for objects put into an Amazon S3 bucket by the S3 File Gateway.
-
#encryption_type ⇒ String
A value that specifies the type of server-side encryption that the file share will use for the data that it stores in Amazon S3.
-
#file_share_arn ⇒ String
The Amazon Resource Name (ARN) of the SMB file share that you want to update.
-
#file_share_name ⇒ String
The name of the file share.
-
#guess_mime_type_enabled ⇒ Boolean
A value that enables guessing of the MIME type for uploaded objects based on file extensions.
-
#invalid_user_list ⇒ Array<String>
A list of users or groups in the Active Directory that are not allowed to access the file share.
-
#kms_encrypted ⇒ Boolean
Optional.
-
#kms_key ⇒ String
Optional.
-
#notification_policy ⇒ String
The notification policy of the file share.
-
#object_acl ⇒ String
A value that sets the access control list (ACL) permission for objects in the S3 bucket that a S3 File Gateway puts objects into.
-
#oplocks_enabled ⇒ Boolean
Specifies whether opportunistic locking is enabled for the SMB file share.
-
#read_only ⇒ Boolean
A value that sets the write status of a file share.
-
#requester_pays ⇒ Boolean
A value that sets who pays the cost of the request and the cost associated with data download from the S3 bucket.
-
#smbacl_enabled ⇒ Boolean
Set this value to
trueto enable access control list (ACL) on the SMB file share. -
#valid_user_list ⇒ Array<String>
A list of users or groups in the Active Directory that are allowed to access the file share.
Instance Attribute Details
#access_based_enumeration ⇒ Boolean
The files and folders on this share will only be visible to users with read access.
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#admin_user_list ⇒ Array<String>
A list of users or groups in the Active Directory that have
administrator rights to the file share. A group must be prefixed
with the @ character. Acceptable formats include: DOMAIN\User1,
user1, @group1, and @DOMAIN\group1. Can only be set if
Authentication is set to ActiveDirectory.
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#audit_destination_arn ⇒ String
The Amazon Resource Name (ARN) of the storage used for audit logs.
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#cache_attributes ⇒ Types::CacheAttributes
Specifies refresh cache information for the file share.
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#case_sensitivity ⇒ String
The case of an object name in an Amazon S3 bucket. For
ClientSpecified, the client determines the case sensitivity. For
CaseSensitive, the gateway determines the case sensitivity. The
default value is ClientSpecified.
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#default_storage_class ⇒ String
The default storage class for objects put into an Amazon S3 bucket
by the S3 File Gateway. The default value is S3_STANDARD.
Optional.
Valid Values: S3_STANDARD | S3_INTELLIGENT_TIERING |
S3_STANDARD_IA | S3_ONEZONE_IA
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#encryption_type ⇒ String
A value that specifies the type of server-side encryption that the file share will use for the data that it stores in Amazon S3.
EncryptionType instead of KMSEncrypted to set
the file share encryption method. You do not need to provide values
for both parameters.
If values for both parameters exist in the same request, then the
specified encryption methods must not conflict. For example, if
EncryptionType is SseS3, then KMSEncrypted must be false. If
EncryptionType is SseKms or DsseKms, then KMSEncrypted must
be true.
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#file_share_arn ⇒ String
The Amazon Resource Name (ARN) of the SMB file share that you want to update.
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#file_share_name ⇒ String
The name of the file share. Optional.
FileShareName must be set if an S3 prefix name is set in
LocationARN, or if an access point or access point alias is used.
A valid SMB file share name cannot contain the following characters:
[,],#,;,<,>,:,",``,/,|,?,*,+, or ASCII
control characters 1-31.
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#guess_mime_type_enabled ⇒ Boolean
A value that enables guessing of the MIME type for uploaded objects
based on file extensions. Set this value to true to enable MIME
type guessing, otherwise set to false. The default value is
true.
Valid Values: true | false
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#invalid_user_list ⇒ Array<String>
A list of users or groups in the Active Directory that are not
allowed to access the file share. A group must be prefixed with the
@ character. Acceptable formats include: DOMAIN\User1, user1,
@group1, and @DOMAIN\group1. Can only be set if Authentication
is set to ActiveDirectory.
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#kms_encrypted ⇒ Boolean
Optional. Set to true to use Amazon S3 server-side encryption with
your own KMS key (SSE-KMS), or false to use a key managed by
Amazon S3 (SSE-S3). To use dual-layer encryption (DSSE-KMS), set the
EncryptionType parameter instead.
EncryptionType instead of KMSEncrypted to set
the file share encryption method. You do not need to provide values
for both parameters.
If values for both parameters exist in the same request, then the
specified encryption methods must not conflict. For example, if
EncryptionType is SseS3, then KMSEncrypted must be false. If
EncryptionType is SseKms or DsseKms, then KMSEncrypted must
be true.
Valid Values: true | false
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#kms_key ⇒ String
Optional. The Amazon Resource Name (ARN) of a symmetric customer
master key (CMK) used for Amazon S3 server-side encryption. Storage
Gateway does not support asymmetric CMKs. This value must be set if
KMSEncrypted is true, or if EncryptionType is SseKms or
DsseKms.
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#notification_policy ⇒ String
The notification policy of the file share. SettlingTimeInSeconds
controls the number of seconds to wait after the last point in time
a client wrote to a file before generating an ObjectUploaded
notification. Because clients can make many small writes to files,
it's best to set this parameter for as long as possible to avoid
generating multiple notifications for the same file in a small time
period.
SettlingTimeInSeconds has no effect on the timing of the object
uploading to Amazon S3, only the timing of the notification.
This setting is not meant to specify an exact time at which the notification will be sent. In some cases, the gateway might require more than the specified delay time to generate and send notifications.
The following example sets NotificationPolicy on with
SettlingTimeInSeconds set to 60.
{"Upload": {"SettlingTimeInSeconds": 60}}
The following example sets NotificationPolicy off.
{}
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#object_acl ⇒ String
A value that sets the access control list (ACL) permission for
objects in the S3 bucket that a S3 File Gateway puts objects into.
The default value is private.
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#oplocks_enabled ⇒ Boolean
Specifies whether opportunistic locking is enabled for the SMB file share.
Valid Values: true | false
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#read_only ⇒ Boolean
A value that sets the write status of a file share. Set this value
to true to set write status to read-only, otherwise set to
false.
Valid Values: true | false
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#requester_pays ⇒ Boolean
A value that sets who pays the cost of the request and the cost
associated with data download from the S3 bucket. If this value is
set to true, the requester pays the costs; otherwise, the S3
bucket owner pays. However, the S3 bucket owner always pays the cost
of storing data.
RequesterPays is a configuration for the S3 bucket that backs the
file share, so make sure that the configuration on the file share is
the same as the S3 bucket configuration.
Valid Values: true | false
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#smbacl_enabled ⇒ Boolean
Set this value to true to enable access control list (ACL) on the
SMB file share. Set it to false to map file and directory
permissions to the POSIX permissions.
For more information, see Using Windows ACLs to limit SMB file share access in the Amazon S3 File Gateway User Guide.
Valid Values: true | false
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |
#valid_user_list ⇒ Array<String>
A list of users or groups in the Active Directory that are allowed
to access the file share. A group must be prefixed with the @
character. Acceptable formats include: DOMAIN\User1, user1,
@group1, and @DOMAIN\group1. Can only be set if Authentication
is set to ActiveDirectory.
7822 7823 7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 7840 7841 7842 7843 7844 7845 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 7822 class UpdateSMBFileShareInput < Struct.new( :file_share_arn, :encryption_type, :kms_encrypted, :kms_key, :default_storage_class, :object_acl, :read_only, :guess_mime_type_enabled, :requester_pays, :smbacl_enabled, :access_based_enumeration, :admin_user_list, :valid_user_list, :invalid_user_list, :audit_destination_arn, :case_sensitivity, :file_share_name, :cache_attributes, :notification_policy, :oplocks_enabled) SENSITIVE = [] include Aws::Structure end |