Class: Aws::StorageGateway::Types::DescribeTapesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::StorageGateway::Types::DescribeTapesInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-storagegateway/types.rb
Overview
DescribeTapesInput
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#gateway_arn ⇒ String
The Amazon Resource Name (ARN) of the gateway.
-
#limit ⇒ Integer
Specifies that the number of virtual tapes described be limited to the specified number.
-
#marker ⇒ String
A marker value, obtained in a previous call to
DescribeTapes. -
#tape_arns ⇒ Array<String>
Specifies one or more unique Amazon Resource Names (ARNs) that represent the virtual tapes you want to describe.
Instance Attribute Details
#gateway_arn ⇒ String
The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Amazon Web Services Region.
3790 3791 3792 3793 3794 3795 3796 3797 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 3790 class DescribeTapesInput < Struct.new( :gateway_arn, :tape_arns, :marker, :limit) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
Specifies that the number of virtual tapes described be limited to the specified number.
<note markdown=“1”> Amazon Web Services may impose its own limit, if this field is not set.
</note>
3790 3791 3792 3793 3794 3795 3796 3797 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 3790 class DescribeTapesInput < Struct.new( :gateway_arn, :tape_arns, :marker, :limit) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
A marker value, obtained in a previous call to DescribeTapes. This marker indicates which page of results to retrieve.
If not specified, the first page of results is retrieved.
3790 3791 3792 3793 3794 3795 3796 3797 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 3790 class DescribeTapesInput < Struct.new( :gateway_arn, :tape_arns, :marker, :limit) SENSITIVE = [] include Aws::Structure end |
#tape_arns ⇒ Array<String>
Specifies one or more unique Amazon Resource Names (ARNs) that represent the virtual tapes you want to describe. If this parameter is not specified, Tape gateway returns a description of all virtual tapes associated with the specified gateway.
3790 3791 3792 3793 3794 3795 3796 3797 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 3790 class DescribeTapesInput < Struct.new( :gateway_arn, :tape_arns, :marker, :limit) SENSITIVE = [] include Aws::Structure end |