Class: Aws::StorageGateway::Types::DetachVolumeInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::StorageGateway::Types::DetachVolumeInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-storagegateway/types.rb
Overview
AttachVolumeInput
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#force_detach ⇒ Boolean
Set to
trueto forcibly remove the iSCSI connection of the target volume and detach the volume. -
#volume_arn ⇒ String
The Amazon Resource Name (ARN) of the volume to detach from the gateway.
Instance Attribute Details
#force_detach ⇒ Boolean
Set to true to forcibly remove the iSCSI connection of the target volume and detach the volume. The default is false. If this value is set to false, you must manually disconnect the iSCSI connection from the target volume.
Valid Values: true | false
4012 4013 4014 4015 4016 4017 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 4012 class DetachVolumeInput < Struct.new( :volume_arn, :force_detach) SENSITIVE = [] include Aws::Structure end |
#volume_arn ⇒ String
The Amazon Resource Name (ARN) of the volume to detach from the gateway.
4012 4013 4014 4015 4016 4017 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 4012 class DetachVolumeInput < Struct.new( :volume_arn, :force_detach) SENSITIVE = [] include Aws::Structure end |