Class: Aws::StorageGateway::Types::ListFileSharesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::StorageGateway::Types::ListFileSharesInput
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-storagegateway/types.rb
Overview
ListFileShareInput
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#gateway_arn ⇒ String
The Amazon Resource Name (ARN) of the gateway whose file shares you want to list.
-
#limit ⇒ Integer
The maximum number of file shares to return in the response.
-
#marker ⇒ String
Opaque pagination token returned from a previous ListFileShares operation.
Instance Attribute Details
#gateway_arn ⇒ String
The Amazon Resource Name (ARN) of the gateway whose file shares you want to list. If this field is not present, all file shares under your account are listed.
4744 4745 4746 4747 4748 4749 4750 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 4744 class ListFileSharesInput < Struct.new( :gateway_arn, :limit, :marker) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of file shares to return in the response. The value must be an integer with a value greater than zero. Optional.
4744 4745 4746 4747 4748 4749 4750 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 4744 class ListFileSharesInput < Struct.new( :gateway_arn, :limit, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
Opaque pagination token returned from a previous ListFileShares operation. If present, Marker specifies where to continue the list from after a previous call to ListFileShares. Optional.
4744 4745 4746 4747 4748 4749 4750 |
# File 'lib/aws-sdk-storagegateway/types.rb', line 4744 class ListFileSharesInput < Struct.new( :gateway_arn, :limit, :marker) SENSITIVE = [] include Aws::Structure end |